durationtools.rational_to_duration_pair_with_multiple_of_specified_integer_denominator
======================================================================================

.. autofunction:: abjad.tools.durationtools.rational_to_duration_pair_with_multiple_of_specified_integer_denominator
